lambdaisland.dbus.client

Pure-Clojure DBUS client library

Pure-Clojure DBUS client library
raw docstring

agree-unix-fdclj

source

auth-externalclj

source

begin-cmdclj

source

callclj

(call client method-call)
source

crlfclj

source

data-cmdclj

source

ensure-full-readclj

(ensure-full-read chan buf n)

Ensures the ByteBuffer contains at least n bytes starting from its current position. Reads more data from the channel if needed, re-allocating the buffer if required. Returns a buffer positioned at the same logical offset, with at least n bytes available.

Ensures the ByteBuffer contains at least `n` bytes starting from its current
position. Reads more data from the channel if needed, re-allocating the buffer
if required. Returns a buffer positioned at the same logical offset, with at
least `n` bytes available.
sourceraw docstring

hello-callclj

source

iface-infoclj

(iface-info client {:keys [destination path interface member] :as headers})
source

init-client!clj

(init-client! chan & [handler])
source

introspectclj

(introspect client {:keys [destination path]})
(introspect client destination path)
source

introspect*clj

(introspect* client destination path)
source

lsclj

(ls client destination path)
source

method-infoclj

(method-info client {:keys [destination path interface member] :as headers})
source

method-signatureclj

(method-signature client headers)
source

munge-introspectionclj

(munge-introspection {:keys [attrs content]})
source

negotiate-unix-fdclj

source

null-byteclj

source

ok-responseclj

source

path-infoclj

(path-info {:keys [interfaces] :as client}
           {:keys [destination path interface member] :as headers})
source

read-fullyclj

(read-fully channel buffer)

Reads bytes from the SocketChannel into the buffer until the buffer is full (i.e., position reaches limit), or the channel reaches end-of-stream. Returns the total number of bytes read in this call.

Reads bytes from the SocketChannel into the buffer until the buffer
is full (i.e., position reaches limit), or the channel reaches end-of-stream.
Returns the total number of bytes read in this call.
sourceraw docstring

read-handshake-linesclj

(read-handshake-lines chan buffer)
source

reply-expected?clj

(reply-expected? {:keys [interfaces]} {:keys [flags type headers] :as msg})
source

session-sockclj

(session-sock)
source

sock-connclj

(sock-conn sock-loc)
source

sock-readclj

(sock-read buf chan)
source

system-sockclj

(system-sock)
source

write-messageclj

(write-message {:keys [socket buffer serial replies] :as client} msg)
source

write-message*clj

(write-message* {:keys [socket buffer serial replies] :as client} msg)
source

write-strclj

(write-str chan s)
source

cljdoc builds & hosts documentation for Clojure/Script libraries