Read/write the DBUS message format
Read/write the DBUS message format
(alignment t)Byte-alignment required by a D-Bus type. STRUCT and DICT_ENTRY are always 8-byte aligned; ARRAY aligns its 4-byte length; primitives align to their natural size; SIGNATURE, BYTE and VARIANT are 1-byte aligned.
Byte-alignment required by a D-Bus type. STRUCT and DICT_ENTRY are always 8-byte aligned; ARRAY aligns its 4-byte length; primitives align to their natural size; SIGNATURE, BYTE and VARIANT are 1-byte aligned.
(write-message buf
{:keys [endian type flags headers version serial body]
:or {version 1 endian :LITTLE_ENDIAN}})(write-to-str f & args)Testing utility, takes a function that takes a buffer as its first argument, and any arguments to that function, calls it on a new buffer, then converts to String.
Testing utility, takes a function that takes a buffer as its first argument, and any arguments to that function, calls it on a new buffer, then converts to String.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |