lambdaisland.dbus.systemd

Convenience functions for talking to systemd over the system bus.

Convenience functions for talking to systemd over the system bus.
raw docstring

freeze-unitclj

(freeze-unit client name)
source

get-default-targetclj

(get-default-target client)
source

get-unitclj

(get-unit client name)

Return the object path for the given unit.

Return the object path for the given unit.
sourceraw docstring

get-unit-processesclj

(get-unit-processes client name)
source

kill-unitclj

(kill-unit client name who signal)

Send a signal to all processes of the unit. who is one of main, control or all, signal is the signal number.

Send a signal to all processes of the unit. `who` is one of `main`,
`control` or `all`, `signal` is the signal number.
sourceraw docstring

list-jobsclj

(list-jobs client)
source

list-unit-filesclj

(list-unit-files client)
source

list-unitsclj

(list-units client)
source

load-unitclj

(load-unit client name)
source

manager-callclj

(manager-call client member & args)

Call a method on the org.freedesktop.systemd1.Manager interface.

Call a method on the org.freedesktop.systemd1.Manager interface.
sourceraw docstring

reloadclj

(reload client)
source

reload-or-restart-unitclj

(reload-or-restart-unit client name mode)
source

reload-or-try-restart-unitclj

(reload-or-try-restart-unit client name mode)
source

reload-unitclj

(reload-unit client name mode)
source

reset-failedclj

(reset-failed client)
source

reset-failed-unitclj

(reset-failed-unit client name)
source

restart-unitclj

(restart-unit client name mode)
source

set-default-targetclj

(set-default-target client name force)
source

start-transient-unitclj

(start-transient-unit client name mode properties aux)

properties: a(sv) aux: a(sa(sv))

properties: a(sv)
aux: a(sa(sv))
sourceraw docstring

start-unitclj

(start-unit client name mode)

Start the unit. mode is one of replace, fail, isolate, ignore-dependencies or ignore-requirements. Returns the job path.

Start the unit. `mode` is one of `replace`, `fail`, `isolate`,
`ignore-dependencies` or `ignore-requirements`. Returns the job path.
sourceraw docstring

stop-unitclj

(stop-unit client name mode)
source

thaw-unitclj

(thaw-unit client name)
source

try-restart-unitclj

(try-restart-unit client name mode)
source

cljdoc builds & hosts documentation for Clojure/Script libraries