Pure-Clojure DBUS client library
Pure-Clojure DBUS client library
(ensure-full-read chan buf n)Ensures the ByteBuffer contains at least n bytes starting from its current
position. Reads more data from the channel if needed, re-allocating the buffer
if required. Returns a buffer positioned at the same logical offset, with at
least n bytes available.
Ensures the ByteBuffer contains at least `n` bytes starting from its current position. Reads more data from the channel if needed, re-allocating the buffer if required. Returns a buffer positioned at the same logical offset, with at least `n` bytes available.
(introspect client {:keys [destination path]})(introspect client destination path)(path-info {:keys [interfaces] :as client}
{:keys [destination path interface member] :as headers})(read-fully channel buffer)Reads bytes from the SocketChannel into the buffer until the buffer is full (i.e., position reaches limit), or the channel reaches end-of-stream. Returns the total number of bytes read in this call.
Reads bytes from the SocketChannel into the buffer until the buffer is full (i.e., position reaches limit), or the channel reaches end-of-stream. Returns the total number of bytes read in this call.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |