Convenience functions for talking to systemd over the system bus.
Convenience functions for talking to systemd over the system bus.
(get-unit client name)Return the object path for the given unit.
Return the object path for the given unit.
(kill-unit client name who signal)Send a signal to all processes of the unit. who is one of main,
control or all, signal is the signal number.
Send a signal to all processes of the unit. `who` is one of `main`, `control` or `all`, `signal` is the signal number.
(manager-call client member & args)Call a method on the org.freedesktop.systemd1.Manager interface.
Call a method on the org.freedesktop.systemd1.Manager interface.
(start-transient-unit client name mode properties aux)properties: a(sv) aux: a(sa(sv))
properties: a(sv) aux: a(sa(sv))
(start-unit client name mode)Start the unit. mode is one of replace, fail, isolate,
ignore-dependencies or ignore-requirements. Returns the job path.
Start the unit. `mode` is one of `replace`, `fail`, `isolate`, `ignore-dependencies` or `ignore-requirements`. Returns the job path.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |